<?php

/*
Generate data for the chart
*/

require_once("../../../wp-config.php");
require_once("../../../wp-includes/wp-db.php");
include_once( 'php-ofc-library/open-flash-chart.php' );

$start_date=date('Y-m-d', strtotime('-31 days'));
$start_date_m1=date('Y-m-d', strtotime('-32 days'));
$end_date=date('Y-m-d', strtotime('yesterday'));

$subscriber_gain=array();
$subscriber_loss=array();
$post_freq=array();
$labels=array();
$max=5;

function myshorten($text='', $len=25){
	if (strlen($text)>$len) {
		$text = substr($text, 0, $len-3).'...';
	}
	return $text;
}

/*******************************************
	Calculate subscribers lost
********************************************/

$sql=<<<EOD
SELECT last_seen, count(ipn) AS lost_subscribers 
FROM $ws_feed_stats->feeddata_name 
WHERE last_seen >= '$start_date' AND last_seen <= '$end_date'
AND last_seen<>first_seen
GROUP BY last_seen
ORDER BY last_seen ASC
EOD;

$lost=$wpdb->get_results($sql);
/*
echo '<pre>';
print_r($lost);
echo '</pre>';
//*/
$last_date = $start_date_m1;
foreach($lost as $daydata) {
	$delta=(strtotime($daydata->last_seen)-strtotime($last_date))/(24*60*60);
	
	if($delta>1){
		for($i=1; $i<$delta; $i++){
			$new_date=date('d M', strtotime("+$i days", strtotime($last_date)));
			$subscriber_loss[] = 0;
			$labels[] = $new_date;
		}
	}
	
	
	$subscriber_loss[] = $daydata->lost_subscribers;
	$labels[] = date('d M', strtotime($daydata->last_seen));
	if ($daydata->lost_subscribers>$max) $max = $daydata->lost_subscribers;
	
	$last_date=$daydata->last_seen;
}

$delta=(strtotime($end_date)-strtotime($last_date))/(24*60*60);
if($delta>0){
	for($i=1; $i<=$delta; $i++){
		$new_date=date('d M', strtotime("+$i days", strtotime($last_date)));
		$subscriber_loss[] = 0;
		$labels[] = $new_date;
	}
}

/*******************************************
	Calculate new subscribers
********************************************/

$sql=<<<EOD
SELECT first_seen, count(ipn) AS new_subscribers 
FROM $ws_feed_stats->feeddata_name 
WHERE first_seen >= '$start_date' AND first_seen <= '$end_date'
AND last_seen<>first_seen
GROUP BY first_seen
ORDER BY first_seen ASC
EOD;

$lost=$wpdb->get_results($sql);

$last_date = $start_date_m1;
foreach($lost as $daydata) {
	$delta=(strtotime($daydata->first_seen)-strtotime($last_date))/(24*60*60);
	
	if($delta>1){
		for($i=1; $i<$delta; $i++){
			$new_date=date('d M', strtotime("+$i days", strtotime($last_date)));
			$subscriber_gain[] = 0;
		}
	}
	
	
	$subscriber_gain[] = $daydata->new_subscribers;
	if ($daydata->new_subscribers>$max) $max = $daydata->new_subscribers;
	
	$last_date=$daydata->first_seen;
}

$delta=(strtotime($end_date)-strtotime($last_date))/(24*60*60);
if($delta>0){
	for($i=1; $i<=$delta; $i++){
		$new_date=date('d M', strtotime("+$i days", strtotime($last_date)));
		$subscriber_gain[] = 0;
	}
}

/*******************************************
	Get posts per day
********************************************/


$sql=<<<EOD
SELECT DATE(post_date) as p_date, post_title, count(id) as post_count
FROM $wpdb->posts
WHERE DATE(post_date) >= '$start_date' AND DATE(post_date) <= '$end_date'
AND post_status='publish' AND post_type='post'
GROUP BY DATE(post_date)
ORDER BY post_date ASC
EOD;

$theposts=$wpdb->get_results($sql);

$last_date = $start_date_m1;
foreach($theposts as $apost) {
	$delta=(strtotime($apost->p_date)-strtotime($last_date))/(24*60*60);
	
	if($delta>1){
		for($i=1; $i<$delta; $i++){
			$new_date=date('d M', strtotime("+$i days", strtotime($last_date)));
			$post_freq[] = 0;
		}
	}
	
	$post_freq[] = $apost->post_count;
	$labels[count($post_freq)-1].=' - '.myshorten($apost->post_title);
	$last_date=$apost->p_date;
}

$delta=(strtotime($end_date)-strtotime($last_date))/(24*60*60);
if($delta>1){
	for($i=1; $i<=$delta; $i++){
		$new_date=date('d M', strtotime("+$i days", strtotime($last_date)));
		$post_freq[] = 0;
	}
}
/*******************************************
	Generate chart data
********************************************/

$g = new graph();
$g->title( 'Feed Subscriber Changes', '{font-size: 20px; color: #736AFF}' );

// we add 3 sets of data:
$g->set_data( $post_freq );
$g->set_data( $subscriber_gain );
$g->set_data( $subscriber_loss );

// we add the 3 line types and key labels
$g->line_dot( 3, 4, '0xA5A5A5', 'Posts', 14);
$g->line_hollow( 3, 4, '0x33EE33', 'First-time subscribers', 14 );
$g->line_hollow( 3, 4, '0xDD5555', 'Last seen subscribers', 14);    // <-- 3px thick + dots

//$g->line_hollow( 2, 4, '0x80a033', 'Bounces', 10 );
// width: 2px, dots: 3px, area alpha: 25% ...
//$g->area_hollow( 2, 3, 25, '0x80a033', 'Total',10 );

$g->set_x_labels( $labels );
$g->set_x_label_style( 10, '0x000000', 0, 7 );

$g->set_y_max( floor($max / 20 + 1) * 20 );
$g->y_label_steps( 4 );
$g->set_y_legend( 'RSS Feed Subscribers', 12, '#736AFF' );
echo $g->render();

?>